var locale = {
    "Add symbol": "Προσθήκη συμβόλου ",
    "Allow scroll wheel zoom?": "Επέτρεψε ζουμ κύλισης",
    "Automatic": "Αυτόματα",
    "Ball": "Καρφίτσα",
    "Cancel": "Άκυρο ",
    "Caption": "Υπόμνημα",
    "Change symbol": "Αλλαγή συμβόλου ",
    "Choose the data format": "Επιλογή μορφής για δεδομένα",
    "Choose the layer of the feature": "Επιλέξτε το επίπεδο του στοιχείου",
    "Circle": "Κύκλος ",
    "Clustered": "Σύμπλεγμα",
    "Data browser": "Δεδομένα Περιήγησης ",
    "Default": "Προεπιλογή ",
    "Default zoom level": "Προεπιλεγμένο επίπεδο μεγέθυνσης",
    "Default: name": "Προεπιλογή: 'Ονομα",
    "Display label": "Εμφάνιση ετικέτας",
    "Display the control to open OpenStreetMap editor": "Εμφάνιση εικονιδίου επεξεργασίας OpenStreetMap",
    "Display the data layers control": "Εμφάνιση εικονιδίου δεδομένα επίπεδων ",
    "Display the embed control": "Εμφάνιση εικονιδίου διαμοιρασμού",
    "Display the fullscreen control": "Εμφάνιση εικονιδίου πλήρους οθόνης ",
    "Display the locate control": "Εμφάνιση εικονιδίου γεωεντοπισμού ",
    "Display the measure control": "Εμφάνιση εικονιδίου μέτρησης",
    "Display the search control": "Εμφάνιση εικονιδίου αναζήτησης",
    "Display the tile layers control": "Εμφάνιση εικονιδίου αλλαγής υποβάθρων",
    "Display the zoom control": "Εμφάνιση εικονιδίου μεγέθυνσης/σμίκρυνσης ",
    "Do you want to display a caption bar?": "Θα επιθυμούσες την εμφάνιση Λεζάντας ;",
    "Do you want to display a minimap?": "Επιθυμείτε την εμφάνιση χάρτη υπομνήματος ;",
    "Do you want to display a panel on load?": "Θα επιθυμούσες την εμφάνιση πινακίδας κατά την φόρτωση ;",
    "Do you want to display popup footer?": "Επιθυμείτε την εμφάνιση αναδυόμενης βάσης ;",
    "Do you want to display the scale control?": "Επιθυμείτε την εμφάνιση κλίμακας ;",
    "Do you want to display the «more» control?": "Επιθυμείτε την εμφάνιση \"περισσότερων\" επιλογών;",
    "Drop": "Ρίψη ",
    "GeoRSS (only link)": "GeoRSS (μόνο σύνδεσμος)",
    "GeoRSS (title + image)": "GeoRSS (τίτλος + εικόνα)",
    "Heatmap": "Χάρτης εγγύτητας",
    "Icon shape": "Μορφή σύμβολο",
    "Icon symbol": "Εικόνα σύμβολο",
    "Inherit": "Μεταβίβαση",
    "Label direction": "Κατεύθυνση ετικέτας ",
    "Label key": "Κλειδί ετικέτας ",
    "Labels are clickable": "Η ετικέτα έχει σύνδεσμο ",
    "None": "Κανένα",
    "On the bottom": "Στο κάτω μέρος",
    "On the left": "Στο αριστερό μέρος",
    "On the right": "Στο δεξί μέρος",
    "On the top": "Στο πάνω μέρος",
    "Popup content template": "Αναδυόμενο παράθυρο περιεχομένου ",
    "Set symbol": "Ορισμός συμβόλου",
    "Side panel": "Πλευρικός πίνακας",
    "Simplify": "Απλοποίησε",
    "Symbol or url": "Σύμβολο ή σύνδεσμος",
    "Table": "Πίνακας",
    "always": "πάντα",
    "clear": "Εκκαθάριση",
    "collapsed": "Κατέρρευσε ",
    "color": "Χρώμα ",
    "dash array": "Διάνυσμα σειράς",
    "define": "Όρισε ",
    "description": "Περιγραφή",
    "expanded": "Ανεπτυγμένος",
    "fill": "Γέμισμα ",
    "fill color": "Χρώμα Γεμίσματος",
    "fill opacity": "Αδιαφάνεια Γεμίσματος",
    "hidden": "Απόκρυψη",
    "iframe": "Παράθυρο εξωτερικού συνδέσμου",
    "inherit": "Μετάβαση",
    "name": "Όνομα",
    "never": "Ποτέ",
    "new window": "Νέο Παράθυρο",
    "no": "όχι",
    "on hover": "Με κατάδειξη",
    "opacity": "Αδιαφάνεια",
    "parent window": "Συγγενές παράθυρο ",
    "stroke": "Πινέλο ",
    "weight": "Βάρος",
    "yes": "ναι",
    "{delay} seconds": "{καθυστέρηση} δευτερόλεπτα",
    "# one hash for main heading": "# ένα hash για τίτλο ",
    "## two hashes for second heading": "## δύο hash για επικεφαλίδα",
    "### three hashes for third heading": "### τρία hash για κεφαλίδα ",
    "**double star for bold**": "**διπλό αστερίσκο για έντονη**",
    "*simple star for italic*": "*μονό αστερίσκο για πλάγια*",
    "--- for an horizontal rule": "---για οριζόντιο διαχωριστικό ",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "Το κόμμα χωρίζει λίστα αριθμών που ορίζονται από ένα διανυσματικό σύνολο πχ.: \"5, 10, 15\".",
    "About": "Σχετικά",
    "Action not allowed :(": "Μη επιτρεπόμενη ενέργεια :(",
    "Activate slideshow mode": "Ενεργοποίηση διαφανειών παρουσίασης ",
    "Add a layer": "Προσθήκη επιπέδου",
    "Add a line to the current multi": "Προσθήκη γραμμής στο παρόν πολυδεδομένο ",
    "Add a new property": "Προσθήκη νέας ιδιότητας",
    "Add a polygon to the current multi": "Προσθήκη πολυγώνου στο παρόν πολυδεδομένο ",
    "Advanced actions": "Εξειδικευμένες ενέργειες ",
    "Advanced properties": "Εξειδικευμένα ιδιότητες ",
    "Advanced transition": "Προχωρημένος μετασχηματισμός ",
    "All properties are imported.": "Εισήχθησαν όλες οι ιδιότητες",
    "Allow interactions": "Επέτρεψε αλληλεπιδράσεις ",
    "An error occured": "Παρουσιάστηκε σφάλμα ",
    "Are you sure you want to cancel your changes?": "Είστε βέβαιος για το ότι θέλετε να ακυρώσετε τις αλλαγές σας;",
    "Are you sure you want to clone this map and all its datalayers?": "Είστε βέβαιος ότι θέλετε να κλωνοποιηθεί  αυτός ο χάρτης και όλα τα επίπεδα δεδομένων του;",
    "Are you sure you want to delete the feature?": "Είστε βέβαιος ότι θέλετε να διαγράφει αυτό το στοιχείο;",
    "Are you sure you want to delete this layer?": "Είσαι σίγουρος για την διαγραφή αυτού του επιπέδου;",
    "Are you sure you want to delete this map?": "Είστε βέβαιος ότι θέλετε να διαγραφεί αυτός ο χάρτης ;",
    "Are you sure you want to delete this property on all the features?": "Είσαι σίγουρος για την διαγραφή αυτής της ιδιότητας από όλα τα στοιχεία; ",
    "Are you sure you want to restore this version?": "Είσαι σίγουρος για την επαναφορά αυτής της εκδοχής ;",
    "Attach the map to my account": "Επισύναψη αυτού του χάρτη στο λογαριασμό μου",
    "Auto": "Αυτόματα",
    "Autostart when map is loaded": "Αυτόματη έναρξη με την φόρτωση του χάρτη ",
    "Bring feature to center": "Κέντραρε το στοιχείο",
    "Browse data": "Περιήγηση δεδομένων ",
    "Cancel edits": "Ακύρωση επεξεργασίας ",
    "Center map on your location": "Κέντραρε τον χάρτη στη θέση σου ",
    "Change map background": "Αλλαγή χαρτογραφικού υποβάθρου ",
    "Change tilelayers": "Αλλαγή επιπέδου ",
    "Choose a preset": "Επιλογή τρέχοντος",
    "Choose the format of the data to import": "Επιλέξτε τη μορφή των δεδομένων για εισαγωγή",
    "Choose the layer to import in": "Επιλέξτε το επίπεδο που θα γίνει η εισαγωγή ",
    "Click last point to finish shape": "Πατήστε στο τελευταίο σημείο για την εισαγωγή του σχήματος",
    "Click to add a marker": "Πατήστε για την εισαγωγή συμβόλου ",
    "Click to continue drawing": "Πατήστε για συνέχεια σχεδίου",
    "Click to edit": "Πατήστε για επεξεργασία",
    "Click to start drawing a line": "Πατήστε για έναρξη σχεδιασμού γραμμής",
    "Click to start drawing a polygon": "Πατήστε για έναρξη σχεδιασμού πολυγώνου ",
    "Clone": "Κλωνοποίηση",
    "Clone of {name}": "Κλωνοποίηση του  {ονόματος}",
    "Clone this feature": "Κλωνοποίηση αυτού του στοιχείου",
    "Clone this map": "Κλωνοποίηση αυτού του χάρτη",
    "Close": "Κλείσιμο ",
    "Clustering radius": "Ακτίνα συμπλέγματος",
    "Comma separated list of properties to use when filtering features": "Διαχωρίστε με κόμμα την λίστα ιδιοτήτων για το φιλτράρισμα των στοιχείων ",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "Οι τιμές που χωρίζονται με κόμματα, tab ή χρώματα. SRS WGS84 υπονοείται. Εισάγονται μόνο γεωμετρίες σημείων. Η εισαγωγή θα εξετάσει τις κεφαλίδες στηλών -Headers- για οποιαδήποτε αναφορά «lat» και «lon» στην αρχή της κεφαλίδας, που δεν είναι ευαίσθητες -case insensitive- . Όλες οι άλλες στήλες εισάγονται ως ιδιότητες.",
    "Continue line": "Συνέχεια γραμμής ",
    "Continue line (Ctrl-click)": "Συνέχεια γραμμής (Ctrl-click)",
    "Coordinates": "Συντεταγμένες ",
    "Credits": "Πιστώσεις ",
    "Current view instead of default map view?": "Αυτή τη προβολή χάρτη αντί της προ επιλεγμένης  ",
    "Custom background": "Προσαρμοσμένο υπόβαθρο",
    "Data is browsable": "Τα δεδομένα είναι περιήγησιμα ",
    "Default interaction options": "Προεπιλεγμένες επιλογές αλληλεπίδρασης",
    "Default properties": "Προεπιλεγμένες ιδιότητες",
    "Default shape properties": "Προεπιλεγμένες ιδιότητες σχημάτων ",
    "Define link to open in a new window on polygon click.": "Προσδιορισμός συνδέσμου για άνοιγμα νέου παραθύρου με κλικ στο πολύγονο ",
    "Delay between two transitions when in play mode": "Καθυστέρηση μεταξύ δύο εναλλαγών κατά την παρουσίαση ",
    "Delete": "Διαγραφή ",
    "Delete all layers": "Διαγραφή όλων των επιπέδων",
    "Delete layer": "Διαγραφή επιπέδου",
    "Delete this feature": "Διαγραφή αυτού του στοιχείου ",
    "Delete this property on all the features": "Διαγραφή αυτής της ιδιότητας από όλα τα στοιχεία",
    "Delete this shape": "Διαγραφή σχήματος",
    "Delete this vertex (Alt-click)": "Διαγραφή αυτής της κορυφής (Alt-click)",
    "Directions from here": "Διαδρομή από εδώ",
    "Disable editing": "Απενεργοποίηση επεξεργασίας ",
    "Display measure": "Εμφάνιση μέτρου ",
    "Display on load": "Εμφάνιση κατά την φόρτωση ",
    "Download": "Λήψη",
    "Download data": "Λήψη δεδομένων",
    "Drag to reorder": "Σύρατε για αναδιάταξη",
    "Draw a line": "Σχεδιασμός γραμμής ",
    "Draw a marker": "Σχεδιασμός σημείου ",
    "Draw a polygon": "Σχεδιασμός πολυγώνου ",
    "Draw a polyline": "Σχεδιασμός σύνθετης γραμμής ",
    "Dynamic": "Δυναμική ",
    "Dynamic properties": "Δυναμικές ιδιότητες  ",
    "Edit": "Επεξεργασία ",
    "Edit feature's layer": "Επεξεργασία στοιχείων επιπέδου",
    "Edit map properties": "Επεξεργασία ιδιοτήτων χάρτη ",
    "Edit map settings": "Επεξεργασία ρυθμίσεων χάρτη",
    "Edit properties in a table": "Επεξεργασία ιδιοτήτων πίνακα",
    "Edit this feature": "Επεξεργασία του στοιχείου ",
    "Editing": "Επεξεργασία",
    "Embed and share this map": "Ένθεση και διαμοιρασμός του χάρτη ",
    "Embed the map": "Ένθεση του χάρτη ",
    "Empty": "Άδειασμα ",
    "Enable editing": "Ενεργοποίηση επεξεργασίας ",
    "Error in the tilelayer URL": "Σφάλμα συνδέσμου υποβάθρου ",
    "Error while fetching {url}": "Σφάλμα ανάκτησης {url}",
    "Exit Fullscreen": "Έξοδος πλήρους οθόνης ",
    "Extract shape to separate feature": "Εξαγωγή σχήματος σε ξεχωριστό στοιχείο",
    "Fetch data each time map view changes.": "Ανάκτηση για δεδομένα σε όλες τις αλλαγές του χάρτη ",
    "Filter keys": "Βασικά φίλτρα",
    "Filter…": "Φίλτρα",
    "Format": "Μορφή",
    "From zoom": "Από μεγέθυνση ",
    "Full map data": "Ολοκληρωμένα δεδομένα χάρτη",
    "Go to «{feature}»": "πήγαινε στο  «{στοιχείο}»",
    "Heatmap intensity property": "Ένταση χαρακτηριστικών χάρτης εγγύτητας ",
    "Heatmap radius": "Ακτίνα χάρτης εγγύτητας ",
    "Help": "Βοήθεια",
    "Hide controls": "Απόκρυψη εργαλείων ελέγχου ",
    "Home": "Αρχική",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "Πόσο απλοποιείται η συνθέτη γραμμή σε κάθε επίπεδο μεγέθυνσης (περισσότερο = ταχύτερη εκτέλεση και γενικότερη αποτύπωση, λιγότερο = περισσότερη ακρίβεια)",
    "If false, the polygon will act as a part of the underlying map.": "Αν ψευδείς, το πολύγονο θα λειτουργήσει σαν μέρος του υποκείμενου χάρτη.",
    "Iframe export options": "iframe παράμετροι εξαγωγής",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe με προσαρμοσμένο ύψος (in px): {{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "Iframe με προσαρμοσμένο ύψος και πλάτος (in px): {{{http://iframe.url.com|height*width}}}",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "Εικόνα με προσαρμοσμένο πλάτος (in px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "Εικόνα: {{http://image.url.com}}",
    "Import": "Εισαγωγή ",
    "Import data": "Εισαγωγή δεδομένων ",
    "Import in a new layer": "Εισαγωγή σε  νέο επίπεδο",
    "Imports all umap data, including layers and settings.": "Εισάγει όλα τα δεδομένα, συμπεριλαμβανομένων επιπέδων και ρυθμίσεων.",
    "Include full screen link?": "Να περιληφθεί σύνδεσμος πλήρους παραθύρου;",
    "Interaction options": "Επιλογές διάδρασης ",
    "Invalid umap data": "Μη έγκυρα δεδομένα umap ",
    "Invalid umap data in {filename}": "Μη έγκυρα δεδομένα σε {filename}",
    "Keep current visible layers": "Διατήρηση τρεχουσών ορατών επιπέδων ",
    "Latitude": "Γεωγραφικό πλάτος",
    "Layer": "Επίπεδο",
    "Layer properties": "Ιδιότητες επιπέδου",
    "Licence": "Άδεια",
    "Limit bounds": "Περιορισμός ορίων",
    "Link to…": "Σύνδεση με ...",
    "Link with text: [[http://example.com|text of the link]]": "Σύνδεση με κείμενο:[[http://example.com|text of the link]]",
    "Long credits": "Αναλυτικές Πιστώσεις ",
    "Longitude": "Γεωγραφικό μήκος",
    "Make main shape": "Κάντε κύριο σχήμα",
    "Manage layers": "Διαχείριση επιπέδων ",
    "Map background credits": "Πιστοποιητικά δημιουργού υποβάθρου ",
    "Map has been attached to your account": "Ο χάρτης έχει συνδεθεί στο λογαριασμό σας",
    "Map has been saved!": "Ο χάρτης έχει αποθηκευτεί!",
    "Map user content has been published under licence": "Ο χάρτης του χρήστη δημοσιεύθηκε με άδεια ",
    "Map's editors": "Οι συντάκτες του χάρτη",
    "Map's owner": "Κάτοχος χάρτη",
    "Merge lines": "Συγχώνευση γραμμών",
    "More controls": "Περισσότερα εργαλεία ",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "Πρέπει να είναι έγκυρη τιμή CSS (π.χ.: DarkBlue ή # 123456)",
    "No licence has been set": "Δεν έχει οριστεί άδεια χρήσης",
    "No results": "Δεν υπάρχουν αποτελέσματα",
    "Only visible features will be downloaded.": "Μόνο τα ορατά στοιχεία θα ληφθούν ",
    "Open download panel": "Ανοίξτε το πλαίσιο λήψης",
    "Open link in…": "Άνοιγμα συνδέσμου σε ...",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "Ανοίξτε αυτό το χάρτη σε έναν επεξεργαστή χαρτών για να παρέχετε πιο ακριβή δεδομένα στο OpenStreetMap",
    "Optional intensity property for heatmap": "Προαιρετική ιδιότητα έντασης για το χάρτης εγγύτητας ",
    "Optional. Same as color if not set.": "Προαιρετικό. Ίδιο χρώμα αν δεν διαμορφωθεί  ",
    "Optionnal.": "Προαιρετικό ",
    "Override clustering radius (default 80)": "Αντικατάσταση ακτίνας συμπλέγματος (προεπιλογή 80)",
    "Override heatmap radius (default 25)": "Αντικατάσταση ακτίνας χάρτης εγγύτητας (προεπιλογή 25)",
    "Paste here your data": "Επικόλλησε εδώ τα δεδομένα σου ",
    "Please be sure the licence is compliant with your use.": "Παρακαλώ χρησιμοποιείστε άδεια που συμμορφώνετε με την χρήση σας ",
    "Please choose a format": "Παρακαλώ επιλέξτε μια μορφή",
    "Please enter the name of the property": "Πληκτρολογήστε το όνομα της ιδιότητας",
    "Please enter the new name of this property": "Εισαγάγετε το νέο όνομα αυτής της ιδιότητας",
    "Please save the map before": "Παρακαλώ αποθηκεύστε το χάρτη πριν",
    "Powered by <a href=\"{leaflet}\">Leaflet</a> and <a href=\"{django}\">Django</a>, glued by <a href=\"{umap}\">uMap project</a>.": "Τροφοδοτείται από <a href=\"{leaflet}\">Leaflet</a> και <a href=\"{django}\">Django</a>, που συνδέθηκαν από το <a href=\"{umap}\">uMap project</a>.",
    "Problem in the response": "Πρόβλημα στην απόκριση ",
    "Problem in the response format": "Πρόβλημα στη μορφή απόκρισης ",
    "Properties imported:": "Ιδιότητες που έχουν εισαχθεί:",
    "Property to use for sorting features": "Ιδιότητα που χρησιμοποιείται για τη ταξινόμηση στοιχείων",
    "Provide an URL here": "Δώστε ένα σύνδεσμο URL εδώ ",
    "Proxy request": "Αίτημα απολακτισμένου μεσολαβητή ",
    "Remote data": "Απομακρυσμένα δεδομένα ",
    "Remove shape from the multi": "Αφαίρεση σχήματος από πολυδεδομένο",
    "Rename this property on all the features": "Μετονομασία αυτής της ιδιότητας από όλα τα στοιχεία",
    "Replace layer content": "Αντικατάσταση περιεχομένου επιπέδου",
    "Restore this version": "Επαναφορά της έκδοσης",
    "Save": "Αποθήκευση",
    "Save anyway": "Αποθήκευσε ούτως ή άλλως",
    "Save current edits": "Αποθήκευση τρέχουσας επεξεργασίας",
    "Save this center and zoom": "Αποθήκευσε αυτό το κέντρο και επίπεδο μεγέθυνσης ",
    "Save this location as new feature": "Αποθήκευσε αυτήν την τοποθεσία ως νέο στοιχείο",
    "Search a place name": "Αναζήτηση ονόματος χώρου",
    "Search location": "Αναζήτηση τοποθεσίας ",
    "Secret edit link is:<br>{link}": "Ο μυστικό σύνδεσμος επεξεργασίας είναι: <br>{link}",
    "See all": "Εμφάνιση όλων ",
    "See data layers": "Εμφάνιση δεδομένα επιπέδων ",
    "See full screen": "Εμφάνιση πλήρους οθόνης ",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "Ρύθμισε την ως ψευδή για την απόκρυψη του επιπέδου από την προβολή διαφανειών, το πρόγραμμα δεδομένα περιήγησης , την αναδυόμενη πλοήγηση ...",
    "Shape properties": "Ιδιότητες σχήματος",
    "Short URL": "Σύντομος σύνδεσμος URL",
    "Short credits": "Σύντομες πιστώσεις.",
    "Show/hide layer": "Εμφάνιση / απόκρυψη επιπέδου",
    "Simple link: [[http://example.com]]": "Απλός σύνδεσμος:[[http://example.com]]",
    "Skipping unkown geometry.type: {type}": "Παράλειψη άγνωστης γεωμετρίας: {type}",
    "Slideshow": "Παρουσίαση",
    "Smart transitions": "Έξυπνες μεταβάσεις",
    "Sort key": "Κλειδί ταξινόμησης ",
    "Split line": "Διαμελισμός γραμμής ",
    "Start a hole here": "Ξεκίνησε μια τρύπα εδώ",
    "Start editing": "Έναρξη επεξεργασίας",
    "Start slideshow": "Έναρξη παρουσίασης",
    "Stop editing": "Τερματισμός επεξεργασίας ",
    "Stop slideshow": "Τερματισμός παρουσίασης",
    "Supported scheme": "Υποστηριζόμενο γράφημα ",
    "Supported variables that will be dynamically replaced": "Υποστηριζόμενες μεταβλητές που θα αντικατασταθούν δυναμικά",
    "Symbol can be either a unicode caracter or an URL. You can use feature properties as variables: ex.: with \"http://myserver.org/images/{name}.png\", the {name} variable will be replaced by the \"name\" value of each marker.": "Το σύμβολο μπορεί να είναι χαρακτήρας unicode ή μια διεύθυνση URL. Μπορείτε να χρησιμοποιήσετε τις ιδιότητες στοιχείων ως μεταβλητές: π.χ. με \"http://myserver.org/images/{name}.png\", η μεταβλητή {name} θα αντικατασταθεί από την τιμή \"όνομα\" κάθε δείκτη.",
    "TMS format": " TMS μορφή",
    "Text color for the cluster label": "Χρώμα κειμένου για την ετικέτα ομαδοποίησης",
    "Text formatting": "Μορφοποίηση κειμένου",
    "The name of the property to use as feature label (ex.: \"nom\")": "Το όνομα της ιδιότητας που θα χρησιμοποιηθεί ως ετικέτα χαρακτηριστικών (π.χ. \"nom\")",
    "The zoom and center have been setted.": "Το επίπεδο μεγέθυνσης  και το κέντρο χάρτη έχουν ρυθμιστεί.",
    "To use if remote server doesn't allow cross domain (slower)": "Για χρήση εάν ο απομακρυσμένος διακομιστής δεν επιτρέπει cross domain (πιο αργή)",
    "To zoom": "Για Μεγέθυνση  ",
    "Toggle edit mode (shift-click)": "Εναλλαγή λειτουργίας επεξεργασίας (shift-click)",
    "Transfer shape to edited feature": "Μεταφορά σχήματος σε επεξεργασμένο στοιχείο",
    "Transform to lines": "Μετασχηματισμός σε γραμμές",
    "Transform to polygon": "Μετασχηματισμός σε πολύγωνο",
    "Type of layer": "Τύπος επιπέδου",
    "Unable to detect format of file {filename}": "Δεν είναι δυνατή η αναγνώριση της μορφής αρχείου {filename}",
    "Untitled layer": "Επίπεδο χωρίς όνομα ",
    "Untitled map": "Χάρτης χωρίς όνομα",
    "Update permissions": "Ενημέρωση δικαιωμάτων ",
    "Update permissions and editors": "Ενημέρωση δικαιωμάτων και συντακτών ",
    "Url": "Σύνδεσμος",
    "Use current bounds": "Χρησιμοποίησε αυτά τα όρια",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "Χρησιμοποιήστε placeholders με τις ιδιότητες στοιχείο μεταξύ παρενθέσεων, π.χ. &#123;name&#125;, θα αντικατασταθούν δυναμικά από τις αντίστοιχες τιμές ",
    "User content credits": "Πιστώσεις περιεχομένου χρήστη",
    "User interface options": "Επιλογές περιβάλλοντος χρήστη",
    "Versions": "Εκδόσεις",
    "View Fullscreen": "Εμφάνιση πλήρους οθόνης",
    "Where do we go from here?": "Πού πάμε από εδώ;",
    "Whether to display or not polygons paths.": "Είτε πρόκειται να εμφανίσετε είτε όχι οδεύσεις πολυγώνων.",
    "Whether to fill polygons with color.": "Είτε πρόκειται να γεμίσετε πολύγωνα με χρώμα.",
    "Who can edit": "Ποιος μπορεί να επεξεργαστεί",
    "Who can view": "Ποιος μπορεί να δει",
    "Will be displayed in the bottom right corner of the map": "Θα εμφανιστεί στην κάτω δεξιά γωνία του χάρτη",
    "Will be visible in the caption of the map": "Θα είναι ορατό στη λεζάντα του χάρτη",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "Οχ!! Κάποιος άλλος φαίνεται να έχει επεξεργαστεί τα δεδομένα. Μπορείτε να αποθηκεύσετε ούτως ή άλλως, αλλά αυτό θα διαγράψει τις αλλαγές που έγιναν από άλλους.",
    "You have unsaved changes.": "Έχετε μη αποθηκευμένες αλλαγές.",
    "Zoom in": "Μεγέθυνση ",
    "Zoom level for automatic zooms": "Επίπεδο ζουμ για αυτόματες μεγεθύνσεις/σμικρύνσεις ",
    "Zoom out": "Σμίκρυνση ",
    "Zoom to layer extent": "Μεγέθυνε στο χώρο κάλυψης του επίπεδου ",
    "Zoom to the next": "Μεγέθυνση στο επόμενο",
    "Zoom to the previous": "Μεγέθυνση στο προηγούμενο",
    "Zoom to this feature": "Μεγέθυνε σε αυτό το στοιχείο",
    "Zoom to this place": "Μεγέθυνση σε αυτό το μέρος",
    "attribution": "Αναφορά",
    "by": "από",
    "display name": "εμφάνιση ονόματος ",
    "height": "ύψος",
    "licence": "άδεια",
    "max East": "μέγιστο ανατολικό ",
    "max North": "Μέγιστο Βόρειο ",
    "max South": "Μέγιστο Νότιο",
    "max West": "Μέγιστο Δυτικό ",
    "max zoom": "Μέγιστη Μεγέθυνση ",
    "min zoom": "Ελάχιστη σμίκρυνση ",
    "next": "επόμενο",
    "previous": "προηγούμενο",
    "width": "πλάτος",
    "{count} errors during import: {message}": "{count} σφάλματα κατά την εισαγωγή:{message}",
    "Measure distances": "Μέτρηση αποστάσεων ",
    "NM": "ΝΜ",
    "kilometers": "Χιλιόμετρα ",
    "km": "χλμ",
    "mi": "μλ",
    "miles": "μίλια ",
    "nautical miles": "Ναυτικά μίλια",
    "{area} acres": "{area} acres",
    "{area} ha": "{area} ha - Εκτάρια ",
    "{area} m&sup2;": "{area} m&sup2;",
    "{area} mi&sup2;": "{area} mi&sup2;",
    "{area} yd&sup2;": "{area} yd&sup2;",
    "{distance} NM": "{distance} NM",
    "{distance} km": "{distance} χλμ",
    "{distance} m": "{distance} μ",
    "{distance} miles": "{distance} μίλια ",
    "{distance} yd": "{distance} yd",
    "1 day": "1 μέρα",
    "1 hour": "1 ώρα",
    "5 min": "5 λεπτά",
    "Cache proxied request": "Cache proxied request",
    "No cache": "No cache",
    "Popup": "Αναδυόμενο",
    "Popup (large)": "Αναδυόμενο (μεγάλο) ",
    "Popup content style": "Στυλ περιεχομένου αναδυόμενου ",
    "Popup shape": "Σχήμα αναδυόμενου "
};
L.registerLocale("el", locale);
L.setLocale("el");